# BaseIdTablesBody

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | **str** | The name for the table. | 
**description** | **str** | The description for the table (optional). If present, must be a non-empty string no longer than 20,000 characters. | [optional] 
**fields** | [**list[FieldModel]**](FieldModel.md) | REQUIRED. A list of JSON objects of min len 1. representing the fields in the table. Refer to field types for supported field types, the write format for field options, and other specifics for certain field types. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

